# Description

Sourcing Modules for Network Protocol Data Exfiltration Project Client

# Installation

`pip install npdep_sourcing`

# Usage

It does not have any direct functionality. It does only provide sourcing modules for NPDEP